# calotron

[![TensorFlow versions](https://img.shields.io/badge/tensorflow-2.11-f57000?style=flat)](https://www.tensorflow.org/versions)
[![PyPI - Python versions](https://img.shields.io/pypi/pyversions/calotron)](https://pypi.python.org/pypi/calotron)
[![PyPI - Version](https://img.shields.io/pypi/v/calotron)](https://pypi.python.org/pypi/calotron)
[![GitHub - Style](https://github.com/mbarbetti/calotron/actions/workflows/style.yml/badge.svg?branch=main)](https://github.com/mbarbetti/calotron/actions/workflows/style.yml)
[![GitHub - Tests](https://github.com/mbarbetti/calotron/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/mbarbetti/calotron/actions/workflows/tests.yml)
[![Codecov](https://codecov.io/gh/mbarbetti/calotron/branch/main/graph/badge.svg?token=DRG8BWC9RR)](https://codecov.io/gh/mbarbetti/calotron)
